@@ -18,9 +18,9 @@
 #ifndef _LOG4CXX_HELPERS_DATE_H
 #define _LOG4CXX_HELPERS_DATE_H
 
-#include <log4cxx/helpers/objectimpl.h>
+#include <log4cxx/helpers/object.h>
 #include <log4cxx/log4cxx.h>
-
+#include <functional>
 
 namespace log4cxx
 {
@@ -32,7 +32,7 @@ namespace helpers
 *      internal strings.
 *
 */
-class LOG4CXX_EXPORT Date : public ObjectImpl
+class LOG4CXX_EXPORT Date : public Object
 {
 		const log4cxx_time_t time;
 
@@ -59,6 +59,22 @@ class LOG4CXX_EXPORT Date : public ObjectImpl
 
 		static log4cxx_time_t getMicrosecondsPerDay();
 		static log4cxx_time_t getMicrosecondsPerSecond();
+		static log4cxx_time_t getCurrentTimeStd();
+		static log4cxx_time_t currentTime();
+
+		/**
+		 * A function that will return the current time(in microseconds) when called
+		 */
+		typedef std::function<log4cxx_time_t()> GetCurrentTimeFn;
+
+		/**
+		 * Set the function that is used to get the current time.
+		 * This is used only for testing purposes and should never be called
+		 * under normal circumstances.
+		 *
+		 * @param fn
+		 */
+		static void setGetCurrentTimeFunction(GetCurrentTimeFn fn);
 
 };
 
