@@ -32,8 +32,9 @@ XFactoryPtr XLogger::factory = XFactoryPtr(new XFactory());
 
 void XLogger::lethal(const LogString& message, const LocationInfo& locationInfo)
 {
-	auto rep = repository;
-	if (!rep || rep->isDisabled(XLevel::LETHAL_INT))
+	auto rep = getLoggerRepository();
+
+	if (rep->isDisabled(XLevel::LETHAL_INT))
 	{
 		return;
 	}
@@ -46,8 +47,9 @@ void XLogger::lethal(const LogString& message, const LocationInfo& locationInfo)
 
 void XLogger::lethal(const LogString& message)
 {
-	auto rep = repository;
-	if (!rep || rep->isDisabled(XLevel::LETHAL_INT))
+	auto rep = getLoggerRepository();
+
+	if (rep->isDisabled(XLevel::LETHAL_INT))
 	{
 		return;
 	}
@@ -70,8 +72,9 @@ LoggerPtr XLogger::getLogger(const helpers::Class& clazz)
 
 void XLogger::trace(const LogString& message, const LocationInfo& locationInfo)
 {
-	auto rep = repository;
-	if (!rep || rep->isDisabled(XLevel::TRACE_INT))
+	auto rep = getLoggerRepository();
+
+	if (rep->isDisabled(XLevel::TRACE_INT))
 	{
 		return;
 	}
@@ -84,8 +87,9 @@ void XLogger::trace(const LogString& message, const LocationInfo& locationInfo)
 
 void XLogger::trace(const LogString& message)
 {
-	auto rep = repository;
-	if (!rep || rep->isDisabled(XLevel::TRACE_INT))
+	auto rep = getLoggerRepository();
+
+	if (rep->isDisabled(XLevel::TRACE_INT))
 	{
 		return;
 	}
