@@ -16,6 +16,7 @@
  */
 
 #include <log4cxx/net/xmlsocketappender.h>
+#include <log4cxx/xml/domconfigurator.h>
 #include "../appenderskeletontestcase.h"
 #include "apr.h"
 
@@ -34,6 +35,7 @@ class XMLSocketAppenderTestCase : public AppenderSkeletonTestCase
 		//
 		LOGUNIT_TEST(testDefaultThreshold);
 		LOGUNIT_TEST(testSetOptionThreshold);
+		//LOGUNIT_TEST(test_fluent_bit);
 
 		LOGUNIT_TEST_SUITE_END();
 
@@ -44,6 +46,17 @@ class XMLSocketAppenderTestCase : public AppenderSkeletonTestCase
 		{
 			return new log4cxx::net::XMLSocketAppender();
 		}
+
+		void test_fluent_bit()
+		{
+			xml::DOMConfigurator::configure("input/xml/fluent-bit.xml");
+			auto log = Logger::getRootLogger();
+			for (int i = 0; i < 100; ++i)
+			{
+				LOG4CXX_INFO(log, "Message '" << i << "'");
+			}
+			LOG4CXX_INFO(log, "Last message");
+		}
 };
 
 LOGUNIT_TEST_SUITE_REGISTRATION(XMLSocketAppenderTestCase);
